import { Component, Host, h, State, Prop, Watch, Event } from '@stencil/core';
import { defaultIconPack } from '../../lib/icons';
import { useLanguage } from '../../lib/lang';
import { Render } from '../../lib/render';
import { defaultConfig } from '../../lib/default-ui-config';
import storeState, { onChange } from '../../lib/store';
import { isV2Theme } from '../../utils/versionTwoApis';
/**
 * A component which handles the sidebar and
 * you can customize which sections you want, and which section you want as the default.
 */
export class DyteSidebar {
  constructor() {
    /** Enabled sections in sidebar */
    this.enabledSections = [
      'chat',
      'polls',
      'participants',
      'plugins',
    ];
    /** Default section */
    this.defaultSection = 'chat';
    /** Config */
    this.config = defaultConfig;
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    /** View type */
    this.view = 'default';
    this.tab = this.defaultSection;
    this.close = () => {
      this.stateUpdate.emit({ activeSidebar: false, sidebar: this.defaultSection });
      storeState.sidebar = this.tab;
    };
  }
  connectedCallback() {
    this.viewChanged(this.view);
    this.statesChanged(this.states);
    onChange('sidebar', () => this.statesChanged());
  }
  disconnectedCallback() {
    this.keydownListener && document.removeEventListener('keydown', this.keydownListener);
  }
  statesChanged(s) {
    const states = s || storeState;
    if ((states === null || states === void 0 ? void 0 : states.sidebar) != null) {
      this.tab = states.sidebar;
    }
  }
  viewChanged(view) {
    if (view === 'full-screen') {
      this.keydownListener = (e) => {
        if (e.key === 'Escape') {
          this.close();
        }
      };
      document.addEventListener('keydown', this.keydownListener);
    }
  }
  filterSections(sections) {
    if (!this.meeting.self.suggestedTheme)
      return sections;
    if (isV2Theme(this.meeting.self.suggestedTheme))
      return sections;
    const theme = this.meeting.self.suggestedTheme;
    if (!theme.controlBar.elements.chat) {
      sections = sections.filter((item) => item !== 'chat');
    }
    else if (!theme.controlBar.elements.polls) {
      sections = sections.filter((item) => item !== 'polls');
    }
    else if (!theme.controlBar.elements.plugins) {
      sections = sections.filter((item) => item !== 'plugins');
    }
    else if (!theme.controlBar.elements.participants) {
      sections = sections.filter((item) => item !== 'participants');
    }
    return sections;
  }
  viewSection(section) {
    this.tab = section;
    this.stateUpdate.emit({ activeSidebar: true, sidebar: this.tab });
    storeState.activeSidebar = true;
    storeState.sidebar = this.tab;
  }
  render() {
    const defaults = {
      meeting: this.meeting,
      config: this.config,
      states: this.states || storeState,
      size: this.size,
      t: this.t,
      iconPack: this.iconPack,
    };
    return (h(Host, null,
      this.view === 'full-screen' && [
        h("h3", { class: "title" }, this.t('About Call')),
        h("div", { id: "mobile-header" }, this.filterSections(this.enabledSections).map((section) => (h("dyte-button", { key: section, variant: "ghost", class: { active: this.tab === section }, onClick: () => this.viewSection(section) }, this.t(section))))),
      ],
      h("dyte-button", { variant: "ghost", kind: "icon", class: "close", onClick: this.close, "aria-label": this.t('Close') },
        h("dyte-icon", { icon: this.iconPack.dismiss })),
      this.view !== 'full-screen' && h("h3", { class: "title" }, this.t(this.tab)),
      this.tab === 'chat' && h(Render, { element: "dyte-chat", defaults: defaults }),
      this.tab === 'polls' && h(Render, { element: "dyte-polls", defaults: defaults }),
      this.tab === 'participants' && h(Render, { element: "dyte-participants", defaults: defaults }),
      this.tab === 'plugins' && h(Render, { element: "dyte-plugins", defaults: defaults })));
  }
  static get is() { return "dyte-sidebar"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["dyte-sidebar.css"]
  }; }
  static get styleUrls() { return {
    "$": ["dyte-sidebar.css"]
  }; }
  static get properties() { return {
    "enabledSections": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "EnabledSidebarSectionsList",
        "resolved": "SidebarSection[]",
        "references": {
          "EnabledSidebarSectionsList": {
            "location": "local"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Enabled sections in sidebar"
      },
      "defaultValue": "[\n    'chat',\n    'polls',\n    'participants',\n    'plugins',\n  ]"
    },
    "defaultSection": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "SidebarSection",
        "resolved": "\"chat\" | \"none\" | \"participants\" | \"plugins\" | \"polls\"",
        "references": {
          "SidebarSection": {
            "location": "local"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Default section"
      },
      "attribute": "default-section",
      "reflect": false,
      "defaultValue": "'chat'"
    },
    "meeting": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Meeting",
        "resolved": "DyteClient",
        "references": {
          "Meeting": {
            "location": "import",
            "path": "../../types/dyte-client"
          }
        }
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Meeting object"
      }
    },
    "states": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "States",
        "resolved": "States",
        "references": {
          "States": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "States object"
      }
    },
    "config": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "UIConfig",
        "resolved": "UIConfig",
        "references": {
          "UIConfig": {
            "location": "import",
            "path": "../../types/ui-config"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Config"
      },
      "defaultValue": "defaultConfig"
    },
    "iconPack": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IconPack",
        "resolved": "{ people: string; chat: string; poll: string; participants: string; rocket: string; call_end: string; share: string; mic_on: string; mic_off: string; video_on: string; video_off: string; share_screen_start: string; share_screen_stop: string; share_screen_person: string; clock: string; dismiss: string; send: string; search: string; more_vertical: string; chevron_down: string; chevron_up: string; chevron_left: string; chevron_right: string; settings: string; wifi: string; speaker: string; download: string; full_screen_maximize: string; full_screen_minimize: string; copy: string; attach: string; image: string; emoji_multiple: string; vertical_scroll: string; vertical_scroll_disabled: string; image_off: string; disconnected: string; wand: string; recording: string; subtract: string; stop_recording: string; warning: string; pin: string; pin_off: string; spinner: string; }",
        "references": {
          "IconPack": {
            "location": "import",
            "path": "../../lib/icons"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Icon pack"
      },
      "defaultValue": "defaultIconPack"
    },
    "t": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "resolved": "(key: \"audio\" | \"video\" | \"chat\" | \"participants\" | \"polls\" | \"plugins\" | \"mic_off\" | \"mic_on\" | \"video_off\" | \"video_on\" | \"left_meeting\" | \"share_screen_start\" | \"share_screen_stop\" | \"leave\" | \"dismiss\" | \"page\" | \"settings\" | \"connection\" | \"leave_confirmation\" | \"end_meeting_for_all\" | \"cancel\" | \"perm_browser_denied\" | \"perm_sys_denied\" | \"perm_denied_title\" | \"perm_denied_text\" | (string & {})) => string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Language"
      },
      "defaultValue": "useLanguage()"
    },
    "size": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Size",
        "resolved": "\"lg\" | \"md\" | \"sm\" | \"xl\"",
        "references": {
          "Size": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Size"
      },
      "attribute": "size",
      "reflect": true
    },
    "view": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "SidebarView",
        "resolved": "\"default\" | \"full-screen\" | \"sidebar\"",
        "references": {
          "SidebarView": {
            "location": "local"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "View type"
      },
      "attribute": "view",
      "reflect": true,
      "defaultValue": "'default'"
    }
  }; }
  static get states() { return {
    "tab": {}
  }; }
  static get events() { return [{
      "method": "stateUpdate",
      "name": "dyteStateUpdate",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": "Emits updated state data"
      },
      "complexType": {
        "original": "States",
        "resolved": "States",
        "references": {
          "States": {
            "location": "import",
            "path": "../../types/props"
          }
        }
      }
    }]; }
  static get watchers() { return [{
      "propName": "states",
      "methodName": "statesChanged"
    }, {
      "propName": "view",
      "methodName": "viewChanged"
    }]; }
}
